@@ -26,13 +26,13 @@
  */
 
 #include "gnutls_int.h"
-#include <hash_int.h>
+#include "hash_int.h"
 #include "errors.h"
 #include <nettle/sha.h>
 #include <nettle/hmac.h>
 #include <nettle/macros.h>
-#include <sha-aarch64.h>
-#include <algorithms.h>
+#include "sha-aarch64.h"
+#include "algorithms.h"
 
 #ifdef HAVE_LIBNETTLE
 
