@@ -64,77 +64,79 @@ static const struct option long_options[] =
   { "p12-info", no_argument, 0, CHAR_MAX + 13 },
   { "p12-name", required_argument, 0, CHAR_MAX + 14 },
   { "to-p12", no_argument, 0, CHAR_MAX + 15 },
+  { "pbmac1", no_argument, 0, CHAR_MAX + 16 },
   { "key-info", no_argument, 0, 'k' },
-  { "p8-info", no_argument, 0, CHAR_MAX + 16 },
-  { "to-rsa", no_argument, 0, CHAR_MAX + 17 },
+  { "p8-info", no_argument, 0, CHAR_MAX + 17 },
+  { "to-rsa", no_argument, 0, CHAR_MAX + 18 },
   { "generate-privkey", no_argument, 0, 'p' },
-  { "key-type", required_argument, 0, CHAR_MAX + 18 },
-  { "bits", required_argument, 0, CHAR_MAX + 19 },
-  { "curve", required_argument, 0, CHAR_MAX + 20 },
-  { "sec-param", required_argument, 0, CHAR_MAX + 21 },
-  { "to-p8", no_argument, 0, CHAR_MAX + 22 },
+  { "key-type", required_argument, 0, CHAR_MAX + 19 },
+  { "bits", required_argument, 0, CHAR_MAX + 20 },
+  { "curve", required_argument, 0, CHAR_MAX + 21 },
+  { "sec-param", required_argument, 0, CHAR_MAX + 22 },
+  { "to-p8", no_argument, 0, CHAR_MAX + 23 },
   { "pkcs8", no_argument, 0, '8' },
-  { "provable", no_argument, 0, CHAR_MAX + 23 },
-  { "verify-provable-privkey", no_argument, 0, CHAR_MAX + 24 },
-  { "seed", required_argument, 0, CHAR_MAX + 25 },
+  { "provable", no_argument, 0, CHAR_MAX + 24 },
+  { "verify-provable-privkey", no_argument, 0, CHAR_MAX + 25 },
+  { "seed", required_argument, 0, CHAR_MAX + 26 },
   { "crl-info", no_argument, 0, 'l' },
-  { "generate-crl", no_argument, 0, CHAR_MAX + 26 },
-  { "verify-crl", no_argument, 0, CHAR_MAX + 27 },
+  { "generate-crl", no_argument, 0, CHAR_MAX + 27 },
+  { "verify-crl", no_argument, 0, CHAR_MAX + 28 },
   { "verify-chain", no_argument, 0, 'e' },
-  { "verify", no_argument, 0, CHAR_MAX + 28 },
-  { "verify-hostname", required_argument, 0, CHAR_MAX + 29 },
-  { "verify-email", required_argument, 0, CHAR_MAX + 30 },
-  { "verify-purpose", required_argument, 0, CHAR_MAX + 31 },
-  { "verify-allow-broken", no_argument, 0, CHAR_MAX + 32 },
-  { "verify-profile", required_argument, 0, CHAR_MAX + 33 },
-  { "p7-generate", no_argument, 0, CHAR_MAX + 34 },
-  { "p7-sign", no_argument, 0, CHAR_MAX + 35 },
-  { "p7-detached-sign", no_argument, 0, CHAR_MAX + 36 },
-  { "p7-include-cert", no_argument, 0, CHAR_MAX + 37 },
-  { "no-p7-include-cert", no_argument, 0, CHAR_MAX + 38 },
-  { "p7-time", no_argument, 0, CHAR_MAX + 39 },
-  { "no-p7-time", no_argument, 0, CHAR_MAX + 40 },
-  { "p7-show-data", no_argument, 0, CHAR_MAX + 41 },
-  { "no-p7-show-data", no_argument, 0, CHAR_MAX + 42 },
-  { "p7-info", no_argument, 0, CHAR_MAX + 43 },
-  { "p7-verify", no_argument, 0, CHAR_MAX + 44 },
-  { "smime-to-p7", no_argument, 0, CHAR_MAX + 45 },
-  { "generate-dh-params", no_argument, 0, CHAR_MAX + 46 },
-  { "get-dh-params", no_argument, 0, CHAR_MAX + 47 },
-  { "dh-info", no_argument, 0, CHAR_MAX + 48 },
-  { "load-privkey", required_argument, 0, CHAR_MAX + 49 },
-  { "load-pubkey", required_argument, 0, CHAR_MAX + 50 },
-  { "load-request", required_argument, 0, CHAR_MAX + 51 },
-  { "load-certificate", required_argument, 0, CHAR_MAX + 52 },
-  { "load-ca-privkey", required_argument, 0, CHAR_MAX + 53 },
-  { "load-ca-certificate", required_argument, 0, CHAR_MAX + 54 },
-  { "load-crl", required_argument, 0, CHAR_MAX + 55 },
-  { "load-data", required_argument, 0, CHAR_MAX + 56 },
-  { "password", required_argument, 0, CHAR_MAX + 57 },
-  { "null-password", no_argument, 0, CHAR_MAX + 58 },
-  { "empty-password", no_argument, 0, CHAR_MAX + 59 },
-  { "hex-numbers", no_argument, 0, CHAR_MAX + 60 },
-  { "cprint", no_argument, 0, CHAR_MAX + 61 },
-  { "rsa", no_argument, 0, CHAR_MAX + 62 },
-  { "dsa", no_argument, 0, CHAR_MAX + 63 },
-  { "ecc", no_argument, 0, CHAR_MAX + 64 },
-  { "ecdsa", no_argument, 0, CHAR_MAX + 65 },
-  { "hash", required_argument, 0, CHAR_MAX + 66 },
-  { "salt-size", required_argument, 0, CHAR_MAX + 67 },
-  { "inder", no_argument, 0, CHAR_MAX + 68 },
-  { "inraw", no_argument, 0, CHAR_MAX + 70 },
-  { "no-inder", no_argument, 0, CHAR_MAX + 69 },
-  { "outder", no_argument, 0, CHAR_MAX + 71 },
-  { "outraw", no_argument, 0, CHAR_MAX + 73 },
-  { "no-outder", no_argument, 0, CHAR_MAX + 72 },
-  { "disable-quick-random", no_argument, 0, CHAR_MAX + 74 },
-  { "template", required_argument, 0, CHAR_MAX + 75 },
-  { "stdout-info", no_argument, 0, CHAR_MAX + 76 },
-  { "ask-pass", no_argument, 0, CHAR_MAX + 77 },
-  { "pkcs-cipher", required_argument, 0, CHAR_MAX + 78 },
-  { "provider", required_argument, 0, CHAR_MAX + 79 },
-  { "text", no_argument, 0, CHAR_MAX + 80 },
-  { "no-text", no_argument, 0, CHAR_MAX + 81 },
+  { "verify", no_argument, 0, CHAR_MAX + 29 },
+  { "verify-hostname", required_argument, 0, CHAR_MAX + 30 },
+  { "verify-email", required_argument, 0, CHAR_MAX + 31 },
+  { "verify-purpose", required_argument, 0, CHAR_MAX + 32 },
+  { "verify-allow-broken", no_argument, 0, CHAR_MAX + 33 },
+  { "verify-profile", required_argument, 0, CHAR_MAX + 34 },
+  { "p7-generate", no_argument, 0, CHAR_MAX + 35 },
+  { "p7-sign", no_argument, 0, CHAR_MAX + 36 },
+  { "p7-detached-sign", no_argument, 0, CHAR_MAX + 37 },
+  { "p7-include-cert", no_argument, 0, CHAR_MAX + 38 },
+  { "no-p7-include-cert", no_argument, 0, CHAR_MAX + 39 },
+  { "p7-time", no_argument, 0, CHAR_MAX + 40 },
+  { "no-p7-time", no_argument, 0, CHAR_MAX + 41 },
+  { "p7-show-data", no_argument, 0, CHAR_MAX + 42 },
+  { "no-p7-show-data", no_argument, 0, CHAR_MAX + 43 },
+  { "p7-info", no_argument, 0, CHAR_MAX + 44 },
+  { "p7-verify", no_argument, 0, CHAR_MAX + 45 },
+  { "smime-to-p7", no_argument, 0, CHAR_MAX + 46 },
+  { "generate-dh-params", no_argument, 0, CHAR_MAX + 47 },
+  { "get-dh-params", no_argument, 0, CHAR_MAX + 48 },
+  { "dh-info", no_argument, 0, CHAR_MAX + 49 },
+  { "load-privkey", required_argument, 0, CHAR_MAX + 50 },
+  { "load-pubkey", required_argument, 0, CHAR_MAX + 51 },
+  { "load-request", required_argument, 0, CHAR_MAX + 52 },
+  { "load-certificate", required_argument, 0, CHAR_MAX + 53 },
+  { "load-ca-privkey", required_argument, 0, CHAR_MAX + 54 },
+  { "load-ca-certificate", required_argument, 0, CHAR_MAX + 55 },
+  { "load-crl", required_argument, 0, CHAR_MAX + 56 },
+  { "load-data", required_argument, 0, CHAR_MAX + 57 },
+  { "password", required_argument, 0, CHAR_MAX + 58 },
+  { "null-password", no_argument, 0, CHAR_MAX + 59 },
+  { "empty-password", no_argument, 0, CHAR_MAX + 60 },
+  { "hex-numbers", no_argument, 0, CHAR_MAX + 61 },
+  { "cprint", no_argument, 0, CHAR_MAX + 62 },
+  { "rsa", no_argument, 0, CHAR_MAX + 63 },
+  { "dsa", no_argument, 0, CHAR_MAX + 64 },
+  { "ecc", no_argument, 0, CHAR_MAX + 65 },
+  { "ecdsa", no_argument, 0, CHAR_MAX + 66 },
+  { "hash", required_argument, 0, CHAR_MAX + 67 },
+  { "salt-size", required_argument, 0, CHAR_MAX + 68 },
+  { "label", required_argument, 0, CHAR_MAX + 69 },
+  { "inder", no_argument, 0, CHAR_MAX + 70 },
+  { "inraw", no_argument, 0, CHAR_MAX + 72 },
+  { "no-inder", no_argument, 0, CHAR_MAX + 71 },
+  { "outder", no_argument, 0, CHAR_MAX + 73 },
+  { "outraw", no_argument, 0, CHAR_MAX + 75 },
+  { "no-outder", no_argument, 0, CHAR_MAX + 74 },
+  { "disable-quick-random", no_argument, 0, CHAR_MAX + 76 },
+  { "template", required_argument, 0, CHAR_MAX + 77 },
+  { "stdout-info", no_argument, 0, CHAR_MAX + 78 },
+  { "ask-pass", no_argument, 0, CHAR_MAX + 79 },
+  { "pkcs-cipher", required_argument, 0, CHAR_MAX + 80 },
+  { "provider", required_argument, 0, CHAR_MAX + 81 },
+  { "text", no_argument, 0, CHAR_MAX + 82 },
+  { "no-text", no_argument, 0, CHAR_MAX + 83 },
   { "version", optional_argument, 0, 'v' },
   { "help", no_argument, 0, 'h' },
   { "more-help", no_argument, 0, '!' },
@@ -251,15 +253,19 @@ process_options (int argc, char **argv)
         opts->present.to_p12 = true;
         opts->enabled.to_p12 = true;
         break;
+      case CHAR_MAX + 16: /* --pbmac1 */
+        opts->present.pbmac1 = true;
+        opts->enabled.pbmac1 = true;
+        break;
       case 'k':
         opts->present.key_info = true;
         opts->enabled.key_info = true;
         break;
-      case CHAR_MAX + 16: /* --p8-info */
+      case CHAR_MAX + 17: /* --p8-info */
         opts->present.p8_info = true;
         opts->enabled.p8_info = true;
         break;
-      case CHAR_MAX + 17: /* --to-rsa */
+      case CHAR_MAX + 18: /* --to-rsa */
         opts->present.to_rsa = true;
         opts->enabled.to_rsa = true;
         break;
@@ -267,28 +273,28 @@ process_options (int argc, char **argv)
         opts->present.generate_privkey = true;
         opts->enabled.generate_privkey = true;
         break;
-      case CHAR_MAX + 18: /* --key-type */
+      case CHAR_MAX + 19: /* --key-type */
         opts->present.key_type = true;
         opts->arg.key_type = optarg;
         opts->enabled.key_type = true;
         break;
-      case CHAR_MAX + 19: /* --bits */
+      case CHAR_MAX + 20: /* --bits */
         opts->present.bits = true;
         opts->arg.bits = optarg;
         opts->value.bits = parse_number(optarg);
         opts->enabled.bits = true;
         break;
-      case CHAR_MAX + 20: /* --curve */
+      case CHAR_MAX + 21: /* --curve */
         opts->present.curve = true;
         opts->arg.curve = optarg;
         opts->enabled.curve = true;
         break;
-      case CHAR_MAX + 21: /* --sec-param */
+      case CHAR_MAX + 22: /* --sec-param */
         opts->present.sec_param = true;
         opts->arg.sec_param = optarg;
         opts->enabled.sec_param = true;
         break;
-      case CHAR_MAX + 22: /* --to-p8 */
+      case CHAR_MAX + 23: /* --to-p8 */
         opts->present.to_p8 = true;
         opts->enabled.to_p8 = true;
         break;
@@ -296,15 +302,15 @@ process_options (int argc, char **argv)
         opts->present.pkcs8 = true;
         opts->enabled.pkcs8 = true;
         break;
-      case CHAR_MAX + 23: /* --provable */
+      case CHAR_MAX + 24: /* --provable */
         opts->present.provable = true;
         opts->enabled.provable = true;
         break;
-      case CHAR_MAX + 24: /* --verify-provable-privkey */
+      case CHAR_MAX + 25: /* --verify-provable-privkey */
         opts->present.verify_provable_privkey = true;
         opts->enabled.verify_provable_privkey = true;
         break;
-      case CHAR_MAX + 25: /* --seed */
+      case CHAR_MAX + 26: /* --seed */
         opts->present.seed = true;
         opts->arg.seed = optarg;
         opts->enabled.seed = true;
@@ -313,11 +319,11 @@ process_options (int argc, char **argv)
         opts->present.crl_info = true;
         opts->enabled.crl_info = true;
         break;
-      case CHAR_MAX + 26: /* --generate-crl */
+      case CHAR_MAX + 27: /* --generate-crl */
         opts->present.generate_crl = true;
         opts->enabled.generate_crl = true;
         break;
-      case CHAR_MAX + 27: /* --verify-crl */
+      case CHAR_MAX + 28: /* --verify-crl */
         opts->present.verify_crl = true;
         opts->enabled.verify_crl = true;
         break;
@@ -325,229 +331,234 @@ process_options (int argc, char **argv)
         opts->present.verify_chain = true;
         opts->enabled.verify_chain = true;
         break;
-      case CHAR_MAX + 28: /* --verify */
+      case CHAR_MAX + 29: /* --verify */
         opts->present.verify = true;
         opts->enabled.verify = true;
         break;
-      case CHAR_MAX + 29: /* --verify-hostname */
+      case CHAR_MAX + 30: /* --verify-hostname */
         opts->present.verify_hostname = true;
         opts->arg.verify_hostname = optarg;
         opts->enabled.verify_hostname = true;
         break;
-      case CHAR_MAX + 30: /* --verify-email */
+      case CHAR_MAX + 31: /* --verify-email */
         opts->present.verify_email = true;
         opts->arg.verify_email = optarg;
         opts->enabled.verify_email = true;
         break;
-      case CHAR_MAX + 31: /* --verify-purpose */
+      case CHAR_MAX + 32: /* --verify-purpose */
         opts->present.verify_purpose = true;
         opts->arg.verify_purpose = optarg;
         opts->enabled.verify_purpose = true;
         break;
-      case CHAR_MAX + 32: /* --verify-allow-broken */
+      case CHAR_MAX + 33: /* --verify-allow-broken */
         opts->present.verify_allow_broken = true;
         opts->enabled.verify_allow_broken = true;
         break;
-      case CHAR_MAX + 33: /* --verify-profile */
+      case CHAR_MAX + 34: /* --verify-profile */
         opts->present.verify_profile = true;
         opts->arg.verify_profile = optarg;
         opts->enabled.verify_profile = true;
         break;
-      case CHAR_MAX + 34: /* --p7-generate */
+      case CHAR_MAX + 35: /* --p7-generate */
         opts->present.p7_generate = true;
         opts->enabled.p7_generate = true;
         break;
-      case CHAR_MAX + 35: /* --p7-sign */
+      case CHAR_MAX + 36: /* --p7-sign */
         opts->present.p7_sign = true;
         opts->enabled.p7_sign = true;
         break;
-      case CHAR_MAX + 36: /* --p7-detached-sign */
+      case CHAR_MAX + 37: /* --p7-detached-sign */
         opts->present.p7_detached_sign = true;
         opts->enabled.p7_detached_sign = true;
         break;
-      case CHAR_MAX + 37: /* --p7-include-cert */
+      case CHAR_MAX + 38: /* --p7-include-cert */
         opts->present.p7_include_cert = true;
         opts->enabled.p7_include_cert = true;
         break;
-      case CHAR_MAX + 38: /* --no-p7-include-cert */
+      case CHAR_MAX + 39: /* --no-p7-include-cert */
         opts->present.p7_include_cert = true;
         opts->enabled.p7_include_cert = false;
         break;
-      case CHAR_MAX + 39: /* --p7-time */
+      case CHAR_MAX + 40: /* --p7-time */
         opts->present.p7_time = true;
         opts->enabled.p7_time = true;
         break;
-      case CHAR_MAX + 40: /* --no-p7-time */
+      case CHAR_MAX + 41: /* --no-p7-time */
         opts->present.p7_time = true;
         opts->enabled.p7_time = false;
         break;
-      case CHAR_MAX + 41: /* --p7-show-data */
+      case CHAR_MAX + 42: /* --p7-show-data */
         opts->present.p7_show_data = true;
         opts->enabled.p7_show_data = true;
         break;
-      case CHAR_MAX + 42: /* --no-p7-show-data */
+      case CHAR_MAX + 43: /* --no-p7-show-data */
         opts->present.p7_show_data = true;
         opts->enabled.p7_show_data = false;
         break;
-      case CHAR_MAX + 43: /* --p7-info */
+      case CHAR_MAX + 44: /* --p7-info */
         opts->present.p7_info = true;
         opts->enabled.p7_info = true;
         break;
-      case CHAR_MAX + 44: /* --p7-verify */
+      case CHAR_MAX + 45: /* --p7-verify */
         opts->present.p7_verify = true;
         opts->enabled.p7_verify = true;
         break;
-      case CHAR_MAX + 45: /* --smime-to-p7 */
+      case CHAR_MAX + 46: /* --smime-to-p7 */
         opts->present.smime_to_p7 = true;
         opts->enabled.smime_to_p7 = true;
         break;
-      case CHAR_MAX + 46: /* --generate-dh-params */
+      case CHAR_MAX + 47: /* --generate-dh-params */
         opts->present.generate_dh_params = true;
         opts->enabled.generate_dh_params = true;
         break;
-      case CHAR_MAX + 47: /* --get-dh-params */
+      case CHAR_MAX + 48: /* --get-dh-params */
         opts->present.get_dh_params = true;
         opts->enabled.get_dh_params = true;
         break;
-      case CHAR_MAX + 48: /* --dh-info */
+      case CHAR_MAX + 49: /* --dh-info */
         opts->present.dh_info = true;
         opts->enabled.dh_info = true;
         break;
-      case CHAR_MAX + 49: /* --load-privkey */
+      case CHAR_MAX + 50: /* --load-privkey */
         opts->present.load_privkey = true;
         opts->arg.load_privkey = optarg;
         opts->enabled.load_privkey = true;
         break;
-      case CHAR_MAX + 50: /* --load-pubkey */
+      case CHAR_MAX + 51: /* --load-pubkey */
         opts->present.load_pubkey = true;
         opts->arg.load_pubkey = optarg;
         opts->enabled.load_pubkey = true;
         break;
-      case CHAR_MAX + 51: /* --load-request */
+      case CHAR_MAX + 52: /* --load-request */
         opts->present.load_request = true;
         opts->arg.load_request = optarg;
         opts->enabled.load_request = true;
         break;
-      case CHAR_MAX + 52: /* --load-certificate */
+      case CHAR_MAX + 53: /* --load-certificate */
         opts->present.load_certificate = true;
         opts->arg.load_certificate = optarg;
         opts->enabled.load_certificate = true;
         break;
-      case CHAR_MAX + 53: /* --load-ca-privkey */
+      case CHAR_MAX + 54: /* --load-ca-privkey */
         opts->present.load_ca_privkey = true;
         opts->arg.load_ca_privkey = optarg;
         opts->enabled.load_ca_privkey = true;
         break;
-      case CHAR_MAX + 54: /* --load-ca-certificate */
+      case CHAR_MAX + 55: /* --load-ca-certificate */
         opts->present.load_ca_certificate = true;
         opts->arg.load_ca_certificate = optarg;
         opts->enabled.load_ca_certificate = true;
         break;
-      case CHAR_MAX + 55: /* --load-crl */
+      case CHAR_MAX + 56: /* --load-crl */
         opts->present.load_crl = true;
         opts->arg.load_crl = optarg;
         opts->enabled.load_crl = true;
         break;
-      case CHAR_MAX + 56: /* --load-data */
+      case CHAR_MAX + 57: /* --load-data */
         opts->present.load_data = true;
         opts->arg.load_data = optarg;
         opts->enabled.load_data = true;
         break;
-      case CHAR_MAX + 57: /* --password */
+      case CHAR_MAX + 58: /* --password */
         opts->present.password = true;
         opts->arg.password = optarg;
         opts->enabled.password = true;
         break;
-      case CHAR_MAX + 58: /* --null-password */
+      case CHAR_MAX + 59: /* --null-password */
         opts->present.null_password = true;
         opts->enabled.null_password = true;
         break;
-      case CHAR_MAX + 59: /* --empty-password */
+      case CHAR_MAX + 60: /* --empty-password */
         opts->present.empty_password = true;
         opts->enabled.empty_password = true;
         break;
-      case CHAR_MAX + 60: /* --hex-numbers */
+      case CHAR_MAX + 61: /* --hex-numbers */
         opts->present.hex_numbers = true;
         opts->enabled.hex_numbers = true;
         break;
-      case CHAR_MAX + 61: /* --cprint */
+      case CHAR_MAX + 62: /* --cprint */
         opts->present.cprint = true;
         opts->enabled.cprint = true;
         break;
-      case CHAR_MAX + 62: /* --rsa */
+      case CHAR_MAX + 63: /* --rsa */
         opts->present.rsa = true;
         opts->enabled.rsa = true;
         break;
-      case CHAR_MAX + 63: /* --dsa */
+      case CHAR_MAX + 64: /* --dsa */
         opts->present.dsa = true;
         opts->enabled.dsa = true;
         break;
-      case CHAR_MAX + 64: /* --ecc */
-      case CHAR_MAX + 65: /* --ecdsa */
+      case CHAR_MAX + 65: /* --ecc */
+      case CHAR_MAX + 66: /* --ecdsa */
         opts->present.ecc = true;
         opts->enabled.ecc = true;
         break;
-      case CHAR_MAX + 66: /* --hash */
+      case CHAR_MAX + 67: /* --hash */
         opts->present.hash = true;
         opts->arg.hash = optarg;
         opts->enabled.hash = true;
         break;
-      case CHAR_MAX + 67: /* --salt-size */
+      case CHAR_MAX + 68: /* --salt-size */
         opts->present.salt_size = true;
         opts->arg.salt_size = optarg;
         opts->value.salt_size = parse_number(optarg);
         opts->enabled.salt_size = true;
         break;
-      case CHAR_MAX + 68: /* --inder */
-      case CHAR_MAX + 70: /* --inraw */
+      case CHAR_MAX + 69: /* --label */
+        opts->present.label = true;
+        opts->arg.label = optarg;
+        opts->enabled.label = true;
+        break;
+      case CHAR_MAX + 70: /* --inder */
+      case CHAR_MAX + 72: /* --inraw */
         opts->present.inder = true;
         opts->enabled.inder = true;
         break;
-      case CHAR_MAX + 69: /* --no-inder */
+      case CHAR_MAX + 71: /* --no-inder */
         opts->present.inder = true;
         opts->enabled.inder = false;
         break;
-      case CHAR_MAX + 71: /* --outder */
-      case CHAR_MAX + 73: /* --outraw */
+      case CHAR_MAX + 73: /* --outder */
+      case CHAR_MAX + 75: /* --outraw */
         opts->present.outder = true;
         opts->enabled.outder = true;
         break;
-      case CHAR_MAX + 72: /* --no-outder */
+      case CHAR_MAX + 74: /* --no-outder */
         opts->present.outder = true;
         opts->enabled.outder = false;
         break;
-      case CHAR_MAX + 74: /* --disable-quick-random */
+      case CHAR_MAX + 76: /* --disable-quick-random */
         opts->present.disable_quick_random = true;
         opts->enabled.disable_quick_random = true;
         break;
-      case CHAR_MAX + 75: /* --template */
+      case CHAR_MAX + 77: /* --template */
         opts->present.template = true;
         opts->arg.template = optarg;
         opts->enabled.template = true;
         break;
-      case CHAR_MAX + 76: /* --stdout-info */
+      case CHAR_MAX + 78: /* --stdout-info */
         opts->present.stdout_info = true;
         opts->enabled.stdout_info = true;
         break;
-      case CHAR_MAX + 77: /* --ask-pass */
+      case CHAR_MAX + 79: /* --ask-pass */
         opts->present.ask_pass = true;
         opts->enabled.ask_pass = true;
         break;
-      case CHAR_MAX + 78: /* --pkcs-cipher */
+      case CHAR_MAX + 80: /* --pkcs-cipher */
         opts->present.pkcs_cipher = true;
         opts->arg.pkcs_cipher = optarg;
         opts->enabled.pkcs_cipher = true;
         break;
-      case CHAR_MAX + 79: /* --provider */
+      case CHAR_MAX + 81: /* --provider */
         opts->present.provider = true;
         opts->arg.provider = optarg;
         opts->enabled.provider = true;
         break;
-      case CHAR_MAX + 80: /* --text */
+      case CHAR_MAX + 82: /* --text */
         opts->present.text = true;
         opts->enabled.text = true;
         break;
-      case CHAR_MAX + 81: /* --no-text */
+      case CHAR_MAX + 83: /* --no-text */
         opts->present.text = true;
         opts->enabled.text = false;
         break;
@@ -659,7 +670,7 @@ process_options (int argc, char **argv)
       if (!OPT_ARG_VERSION || !strcmp (OPT_ARG_VERSION, "c"))
         {
           const char str[] =
-            "certtool 3.8.1\n"
+            "certtool 3.8.6\n"
             "Copyright (C) 2000-2023 Free Software Foundation, and others\n"
             "This is free software. It is licensed for use, modification and\n"
             "redistribution under the terms of the GNU General Public License,\n"
@@ -672,14 +683,14 @@ process_options (int argc, char **argv)
       else if (!strcmp (OPT_ARG_VERSION, "v"))
         {
           const char str[] =
-            "certtool 3.8.1\n";
+            "certtool 3.8.6\n";
           fprintf (stdout, "%s", str);
           exit(0);
         }
       else if (!strcmp (OPT_ARG_VERSION, "n"))
         {
           const char str[] =
-            "certtool 3.8.1\n"
+            "certtool 3.8.6\n"
             "Copyright (C) 2000-2023 Free Software Foundation, and others\n"
             "This is free software. It is licensed for use, modification and\n"
             "redistribution under the terms of the GNU General Public License,\n"
@@ -758,6 +769,7 @@ usage (FILE *out, int status)
     "       --p12-info             Print information on a PKCS #12 structure\n"
     "       --p12-name=str         The PKCS #12 friendly name to use\n"
     "       --to-p12               Generate a PKCS #12 structure\n"
+    "       --pbmac1               Use PBMAC1 in a PKCS #12 structure\n"
     "\n"
     "Private key related options:\n"
     "\n"
@@ -826,6 +838,7 @@ usage (FILE *out, int status)
     "       --cprint               In certain operations it prints the information in C-friendly format\n"
     "       --hash=str             Hash algorithm to use for signing\n"
     "       --salt-size=num        Specify the RSA-PSS key default salt size\n"
+    "       --label=str            Specify the RSA-OAEP label, encoded in hexadecimal\n"
     "       --inder                Use DER format for input certificates, private keys, and DH parameters \n"
     "       --inraw                an alias for the 'inder' option\n"
     "       --outder               Use DER format for output certificates, private keys, and DH parameters\n"
